==> react-native-ui-lib-7.23.3.tgz: package/src/style/designTokensDM.js <==
import { colorsPalette } from "./colorsPalette";
export default {
  // BACKGROUND
  $backgroundDefault: colorsPalette.dark,
  $backgroundElevated: colorsPalette.grey1,
  $backgroundElevatedLight: colorsPalette.grey10,
  $backgroundNeutralHeavy: colorsPalette.grey50,
  $backgroundNeutralIdle: colorsPalette.grey30,
  $backgroundNeutralMedium: colorsPalette.grey10,
  $backgroundNeutral: colorsPalette.grey5,
  $backgroundNeutralLight: colorsPalette.grey1,
  $backgroundPrimaryHeavy: colorsPalette.violet50,
  $backgroundPrimaryMedium: colorsPalette.violet5,
  $backgroundPrimaryLight: colorsPalette.violet1,
  $backgroundGeneralHeavy: colorsPalette.blue50,
  $backgroundGeneralMedium: colorsPalette.blue5,
  $backgroundGeneralLight: colorsPalette.blue1,
  $backgroundSuccessHeavy: colorsPalette.green40,
  $backgroundSuccessLight: colorsPalette.green1,
  $backgroundWarningHeavy: colorsPalette.yellow40,
  $backgroundWarningLight: colorsPalette.yellow1,
  $backgroundMajorLight: colorsPalette.orange1,
  $backgroundMajorHeavy: colorsPalette.orange40,
  $backgroundDangerHeavy: colorsPalette.red40,
  $backgroundDangerLight: colorsPalette.red1,
  $backgroundDisabled: colorsPalette.grey20,
  $backgroundDark: colorsPalette.grey10,
  $backgroundDarkElevated: colorsPalette.grey20,
  $backgroundDarkActive: colorsPalette.grey20,
  $backgroundInverted: colorsPalette.grey80,
  // TEXT
  $textDisabled: colorsPalette.grey20,
  $textDefault: colorsPalette.grey60,
  $textNeutralHeavy: colorsPalette.grey50,
  $textNeutral: colorsPalette.grey40,
  $textNeutralLight: colorsPalette.grey30,
  $textDefaultLight: colorsPalette.grey10,
  $textPrimary: colorsPalette.violet50,
  $textGeneral: colorsPalette.blue50,
  $textSuccess: colorsPalette.green60,
  $textSuccessLight: colorsPalette.green40,
  $textMajor: colorsPalette.orange60,
  $textDanger: colorsPalette.red60,
  $textDangerLight: colorsPalette.red40,
  // ICON
  $iconDefault: colorsPalette.grey60,
  $iconNeutral: colorsPalette.grey50,
  $iconDefaultLight: colorsPalette.grey10,
  $iconPrimary: colorsPalette.violet50,
  $iconPrimaryLight: colorsPalette.violet30,
  $iconGeneral: colorsPalette.blue50,
  $iconGeneralLight: colorsPalette.blue30,
  $iconSuccess: colorsPalette.green60,
  $iconSuccessLight: colorsPalette.green40,
  $iconMajor: colorsPalette.orange60,
  $iconDanger: colorsPalette.red60,
  $iconDangerLight: colorsPalette.red40,
  $iconDisabled: colorsPalette.grey20,
  // OUTLINE
  $outlineDefault: colorsPalette.grey5,
  $outlineDisabled: colorsPalette.grey20,
  $outlineDisabledHeavy: colorsPalette.grey40,
  $outlineNeutral: colorsPalette.grey20,
  $outlineNeutralHeavy: colorsPalette.grey40,
  $outlinePrimary: colorsPalette.violet50,
  $outlineGeneral: colorsPalette.blue50,
  $outlineWarning: colorsPalette.yellow40,
  $outlineDanger: colorsPalette.red40,
  $outlineInverted: colorsPalette.grey10
};

==> react-native-ui-lib-7.31.0.tgz: package/src/style/designTokensDM.js <==
import { colorsPalette } from "./colorsPalette";
export default {
  // BACKGROUND
  $backgroundDefault: colorsPalette.dark,
  $backgroundElevated: colorsPalette.grey1,
  $backgroundElevatedLight: colorsPalette.grey10,
  $backgroundNeutralHeavy: colorsPalette.grey50,
  $backgroundNeutralIdle: colorsPalette.grey30,
  $backgroundNeutralMedium: colorsPalette.grey10,
  $backgroundNeutral: colorsPalette.grey5,
  $backgroundNeutralLight: colorsPalette.grey1,
  $backgroundPrimaryHeavy: colorsPalette.violet50,
  $backgroundPrimaryMedium: colorsPalette.violet5,
  $backgroundPrimaryLight: colorsPalette.violet1,
  $backgroundGeneralHeavy: colorsPalette.blue50,
  $backgroundGeneralMedium: colorsPalette.blue5,
  $backgroundGeneralLight: colorsPalette.blue1,
  $backgroundSuccessHeavy: colorsPalette.green40,
  $backgroundSuccessLight: colorsPalette.green1,
  $backgroundWarningHeavy: colorsPalette.yellow40,
  $backgroundWarningLight: colorsPalette.yellow1,
  $backgroundMajorLight: colorsPalette.orange1,
  $backgroundMajorHeavy: colorsPalette.orange40,
  $backgroundDangerHeavy: colorsPalette.red40,
  $backgroundDangerLight: colorsPalette.red1,
  $backgroundDisabled: colorsPalette.grey20,
  $backgroundDark: colorsPalette.grey10,
  $backgroundDarkElevated: colorsPalette.grey20,
  $backgroundDarkActive: colorsPalette.grey20,
  $backgroundInverted: colorsPalette.grey80,
  // TEXT
  $textDisabled: colorsPalette.grey20,
  $textDefault: colorsPalette.grey60,
  $textNeutralHeavy: colorsPalette.grey50,
  $textNeutral: colorsPalette.grey40,
  $textNeutralLight: colorsPalette.grey30,
  $textDefaultLight: colorsPalette.grey10,
  $textPrimary: colorsPalette.violet50,
  $textGeneral: colorsPalette.blue50,
  $textSuccess: colorsPalette.green60,
  $textSuccessLight: colorsPalette.green40,
  $textMajor: colorsPalette.orange60,
  $textDanger: colorsPalette.red60,
  $textDangerLight: colorsPalette.red40,
  // ICON
  $iconDefault: colorsPalette.grey60,
  $iconNeutral: colorsPalette.grey50,
  $iconDefaultLight: colorsPalette.grey10,
  $iconPrimary: colorsPalette.violet50,
  $iconPrimaryLight: colorsPalette.violet30,
  $iconGeneral: colorsPalette.blue50,
  $iconGeneralLight: colorsPalette.blue30,
  $iconSuccess: colorsPalette.green60,
  $iconSuccessLight: colorsPalette.green40,
  $iconMajor: colorsPalette.orange60,
  $iconDanger: colorsPalette.red60,
  $iconDangerLight: colorsPalette.red40,
  $iconDisabled: colorsPalette.grey20,
  // OUTLINE
  $outlineDefault: colorsPalette.grey5,
  $outlineDisabled: colorsPalette.grey5,
  $outlineDisabledHeavy: colorsPalette.grey40,
  $outlineNeutral: colorsPalette.grey20,
  $outlineNeutralHeavy: colorsPalette.grey40,
  $outlinePrimary: colorsPalette.violet50,
  $outlinePrimaryMedium: colorsPalette.blue5,
  $outlineGeneral: colorsPalette.blue50,
  $outlineWarning: colorsPalette.yellow40,
  $outlineDanger: colorsPalette.red40,
  $outlineInverted: colorsPalette.grey10,
  // BLACK AND WHITE
  $black: colorsPalette.white,
  $white: colorsPalette.black
};
